#
# spec file for package filesystem (Version 10)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           filesystem
License:        GPL v2 or later
Group:          System/Fhs
AutoReqProv:    on
Summary:        Basic Directory Layout
Version:        10
Release:        1.18.38
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      aaa_dir
Provides:       aaa_dir
Source:         directory.list
Source1:        filesystem.links
Source2:        languages
Source64:       directory.list64

%prep
%setup -c -n filesystem -T

%install
function create_dir () {
    local MODE=$1
    local OWNR=$2
    local GRUP=$3
    local NAME=$4
    local XTRA=$5
    local BDIR=`dirname $NAME`
    test -d "$RPM_BUILD_ROOT/$NAME" && { echo "dir $NAME does already exist" ; echo "input out of sequence ?" ; exit 1 ; }
    test -n "$BDIR" -a ! -d $RPM_BUILD_ROOT$BDIR && create_dir 0755 root root $BDIR
    mkdir -m $MODE $RPM_BUILD_ROOT/$NAME
    echo "$XTRA%%dir %%attr($MODE,$OWNR,$GRUP) $NAME" >> filesystem.list
}
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
echo "%%defattr(-,root,root)" > filesystem.list
{
    cat %{SOURCE0}
%ifarch s390x sparc64 x86_64 ppc64 ppc
    cat %{SOURCE64}
%endif
} |
while read MOD OWN GRP NAME ; do
%ifarch s390 s390x
    case $NAME in
	/media/floppy|/media/cdrom|/floppy|/cdrom) continue ;;
    esac
%endif
    case $NAME in
	/media/floppy|/media/cdrom)
	    create_dir $MOD $OWN $GRP $NAME "%%verify(not mode) %%ghost "
	    continue ;;
    esac
    create_dir $MOD $OWN $GRP $NAME
done
for march in \
%ifarch %ix86
i586-suse-linux \
%else
%ifarch ppc
powerpc-suse-linux \
%else
%ifarch ppc64
powerpc64-suse-linux \
%else
%{_target_cpu}-suse-linux \
%endif
%endif
%endif
  ; do
  create_dir 0755 root root /usr/$march
  for xdir in bin include lib ; do
    create_dir 0755 root root /usr/$march/$xdir
  done
done
%ifarch ia64
create_dir 0755 root root /emul/ia32-linux
%endif
# now do the links
while read SRC DEST ; do
case $SRC in
 "") continue ;;
 \#*) echo "comment: $SRC $DEST" ;;
 *) 
    case $SRC in
	/*) test -d $RPM_BUILD_ROOT/$SRC || { echo "link src does not exist" ; exit 1 ; }
	    ;;
	*)  test -d $RPM_BUILD_ROOT/`dirname $DEST`/$SRC || { echo "link src does not exist" ; exit 1 ; }
	    ;;
    esac
    ln -sf $SRC $RPM_BUILD_ROOT$DEST
    echo "%%dir $DEST" >> filesystem.list
    ;;
esac
done < %{SOURCE1}
# Create the locale directories:
while read LANG ; do
  create_dir 0755 root root /usr/share/locale/$LANG/LC_MESSAGES
done < %{SOURCE2}
RPM_INSTALL_PREFIX=$RPM_BUILD_ROOT
export RPM_BUILD_ROOT
# check, if all home directories are present.
UNFOUND=false
UNFOUND_DIRS=
OLDIFS="$IFS"
IFS=":"
while read LOGIN PASSWD UID_T GID_T NAME HOME_DIR SHELL_T ; do
    test "$LOGIN" = "abuild" && continue
    test "$LOGIN" = "icecream" && continue
    test -n "$HOME_DIR" || continue
    test "$UID_T" -gt 100 && continue
    test -d $RPM_BUILD_ROOT/$HOME_DIR && continue
    echo $HOME_DIR does not exist.
    UNFOUND=true
    UNFOUND_DIRS="$UNFOUND_DIRS $HOME_DIR"
done < /etc/passwd
IFS=$OLDIFS
if test "$UNFOUND" = true ; then
    echo There are home directories defined, which are not present.
    echo Unfound: $UNFOUND_DIRS
    exit 1
fi
#
# now check, if all files of aaa_base have a directory in this package
#
NON_EXISTING_DIR=
for FILE in `rpm -ql aaa_base` ; do
    test -d $FILE && continue
    case $FILE in
      /sbin/init.d*|/usr/share/doc/support/*)
             continue
             ;;
    esac
    test -d $RPM_BUILD_ROOT/`dirname $FILE` || {
        echo `dirname $FILE` for $FILE is not in filesystem.
        NON_EXISTING_DIR="$NON_EXISTING_DIR `dirname $FILE`"
    }
done
test -n "$NON_EXISTING_DIR" && {
    echo NON_EXISTING_DIR=$NON_EXISTING_DIR
    exit 1
}

%files -f filesystem.list

%description
This package installs the basic directory structure. It also includes
the home directories of system users.



%changelog
* Wed Apr 22 2009 lrupp@suse.de
- added mg and tl to the list of languages
* Thu Feb 15 2007 joeshaw@suse.de
- added dz to list of languages
* Fri Jan  5 2007 ro@suse.de
- added ne to list of languages
* Sat Mar  4 2006 aj@suse.de
- added fy and tt to languages.
* Tue Jan 31 2006 ro@suse.de
- added km to languages
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 ro@suse.de
- added languages fo,ku,lo,nds,se,ss
* Tue Dec 20 2005 kukuk@suse.de
- Don't check mode for /media/*
* Mon Dec 19 2005 ro@suse.de
- added /dev
* Thu Dec  8 2005 ro@suse.de
- added /usr/share/mime and /usr/share/mime/packages
* Fri Sep 30 2005 lnussel@suse.de
- change /var/games to games:games 775 again (#103186)
* Mon Aug 15 2005 pth@suse.de
- Add zh_HK and it_IT to locale
* Fri Aug 12 2005 ro@suse.de
- changed /var/games to root:root/0755
* Tue Aug  2 2005 cthiel@suse.de
- added te to language list
* Wed Jun 22 2005 gekker@suse.de
- added mi, mt, nso, oc, ven, xh, zu to language list
* Thu Jun  9 2005 ro@suse.de
- add /usr/share/pkgconfig
* Wed May 18 2005 cthiel@suse.de
- added bn_IN and mr to language list
* Tue Apr 12 2005 ro@suse.de
- added ar to language list
* Wed Apr  6 2005 kukuk@suse.de
- Add rw to language list (gcc4)
* Fri Jan 28 2005 gekker@suse.de
- add gu and pa to language list
* Thu Jan 27 2005 gekker@suse.de
- add en_CA to language list
* Wed Nov 10 2004 ro@suse.de
- /var/cache/fonts to 1777 (was set this way in tetex perms)
* Tue Oct 19 2004 ro@suse.de
- remove no from language list (nb,nn now)
* Tue Sep 28 2004 uli@suse.de
- really enable /media on s390* (was missing in directory.list)
* Tue Aug 31 2004 ro@suse.de
- ignore icecream home-dir (might be forced into buildsystem)
* Thu Aug 26 2004 kukuk@suse.de
- removed /etc/httpd tree (Apache1 was dropped)
* Fri Aug 20 2004 ro@suse.de
- removed /var/adm/notify tree (obsolete now)
* Tue Aug 17 2004 ro@suse.de
- added /var/lib/update-messages
  and /usr/share/update-messages (lang subdirs to be done)
* Thu Aug  5 2004 ro@suse.de
- added es_ES to languages
* Thu Jun 24 2004 kukuk@suse.de
- Enable /media on s390/s390x [Bug #42411]
* Thu Apr 15 2004 kukuk@suse.de
- Add /etc/ld.so.conf.d
* Sun Apr  4 2004 mls@suse.de
- made /usr/lib/news owned by root:root as /usr/lib/news/bin
  contains a suid-root program
* Thu Apr  1 2004 kukuk@suse.de
- Add sticky bit to /var/lock
- Change permissions of /var/lock/subsys to root:root, mode 755
* Wed Mar 31 2004 ro@suse.de
- package /media/{cdrom,floppy} as %%ghost (not on s390*)
* Tue Feb 24 2004 ro@suse.de
- ignore missing HOME for abuild user
* Mon Feb 23 2004 ro@suse.de
- /root/.gnupg: mode 700 now (#31982)
* Wed Feb 18 2004 kukuk@suse.de
- Remove ca_ES again
* Mon Feb 16 2004 kukuk@suse.de
- added lang ca_ES
* Mon Feb  9 2004 ro@suse.de
- added /usr/share/java
* Fri Jan 30 2004 schwab@suse.de
- Add /emul/ia32-linux on ia64.
* Tue Nov 18 2003 ro@suse.de
- added lang pt_PT
* Thu Nov  6 2003 olh@suse.de
- add /sys
* Tue Oct 21 2003 ro@suse.de
- fixed leftover permissions from previous change
* Mon Oct 20 2003 ro@suse.de
- adapt to current permissions files
- don't build as root
* Tue Oct 14 2003 meissner@suse.de
- ppc has also lib64 directories (coming from biarch gcc build).
* Thu Sep 25 2003 mmj@suse.de
- Add /etc/xdg and /usr/share/themes according to the new standards
  on freedesktop.org
* Tue Sep  9 2003 kukuk@suse.de
- Add bs, ka, uz and uz@Cyrl to languages
* Fri Aug 29 2003 kukuk@suse.de
- adjust /etc/cups permissions to cups need (make it 0775)
* Tue Aug 26 2003 kssingvo@suse.de
- changed group ownership of /etc/cups (bugzilla#28736)
* Thu Aug 21 2003 ro@suse.de
- added br to languages
* Wed Jul 30 2003 adrian@suse.de
- add ee and es_MX to languages
* Mon Jul 28 2003 adrian@suse.de
- add /usr/share/applications directory
* Mon Jun 23 2003 kukuk@suse.de
- Fix /usr/alpha-suse-linux directory
* Thu Jun 19 2003 mmj@suse.de
- Add missing directories on lib64 platforms
* Fri Jun 13 2003 kukuk@suse.de
- Fix permissions of /etc/uucp
* Fri Jun 13 2003 kukuk@suse.de
- Add /usr/X11R6/share/locale
* Thu Jun 12 2003 kukuk@suse.de
- Add /usr/share/dict
* Thu Jun 12 2003 kukuk@suse.de
- Add new locale directories: kn, li, ml, sr@Latn and yi
* Thu Jun 12 2003 kukuk@suse.de
- Rename i486-suse-linux to i586-suse-linux
* Thu Jun 12 2003 kukuk@suse.de
- Fix permissions of /etc/cups
* Thu Jun 12 2003 kukuk@suse.de
- Add /usr/X11R6/share and /usr/X11R6/share/icons
* Wed Jun 11 2003 ro@suse.de
- added usr/lib*/browser-plugins and usr/share/pixmaps
* Wed Jun 11 2003 kukuk@suse.de
- Add /etc/sysconfig/network and /etc/ppp subdirectories
* Wed Jun 11 2003 kukuk@suse.de
- Add /var/adm/SuSEconfig/{bin,md5}
* Wed Jun 11 2003 kukuk@suse.de
- Add /etc/X11
* Wed Jun 11 2003 kukuk@suse.de
- Add /usr/X11R6/lib/X11/fonts
* Wed Jun 11 2003 kukuk@suse.de
- Add /usr/share/doc/packages with correct permissions
* Tue Jun 10 2003 kukuk@suse.de
- Add usr/share/locale and subdirectories
- Remove usr/share/doc/packages/aaa_base, not needed any longer
* Thu May 15 2003 kukuk@suse.de
- Add include/net, include/sys, include/rpcsvc
* Fri Apr  4 2003 ro@suse.de
- added /etc/skel
* Fri Apr  4 2003 kukuk@suse.de
- changed version to BUILD_DISTRIBUTION_VERSION
* Thu Feb 27 2003 kukuk@suse.de
- Remove /var/named from filelist [Bug #24387]
* Thu Feb 13 2003 mmj@suse.de
- Make filesystem own /etc/cron.d* since we might want to use
  other cron versions.
* Thu Feb 13 2003 mmj@suse.de
- Do not own /etc/cron.daily -- it's owned by cron already
* Tue Jan 14 2003 kukuk@suse.de
- Add /etc/xinetd.d
* Tue Nov  5 2002 ro@suse.de
- removed /var/lib/YaST
- removed /var/adm/current_package_descr (#19665)
* Mon Sep  2 2002 ro@suse.de
- added /var/lib/empty
* Sun Aug  4 2002 ro@suse.de
- added /etc/java
* Thu Aug  1 2002 poeml@suse.de
- move Apache's ServerRoot from /usr/local/httpd to /srv/www
- move homedir of ftp user from /usr/local/ftp to /srv/ftp
* Tue Jul 30 2002 kukuk@suse.de
- use changes and not spec file for version number calculating
* Wed Jul 17 2002 kukuk@suse.de
- Rename package to filesystem
* Thu Jul 11 2002 kukuk@suse.de
- Add /etc/aliases.d (partial fix for Bug #15921)
* Mon Jul  8 2002 kukuk@suse.de
- Remove home dirs for user removed from aaa_base
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Tue Jul  2 2002 ro@suse.de
- removed ircd,squid home dirs
* Tue Jul  2 2002 ro@suse.de
- removed home dirs for dpbox,vscan,wnn,perforce,db4web
* Mon Jun 17 2002 ro@suse.de
- removed pop home
* Fri Jun  7 2002 ro@suse.de
- removed zope home
* Mon Jun  3 2002 ro@suse.de
- removed /usr/share/doc/support
* Sun May 26 2002 ro@suse.de
- removed ingres home dir
* Fri May 24 2002 kukuk@suse.de
- Remove /usr/lib/cyrus and /var/spool/postfix (should be moved
  to postfix and cyrus-imapd)
* Wed May 22 2002 kukuk@suse.de
- Move /var/spool/atjobs to at package
* Tue May 21 2002 ro@suse.de
- no 64bit dirs for "normal" ppc
* Sun May 19 2002 olh@suse.de
- fix specfile
* Sun May 19 2002 olh@suse.de
- add directories for ppc64
* Thu Apr 18 2002 kukuk@suse.de
- x86_64 is 64bit arch
* Wed Apr 10 2002 kukuk@suse.de
- Change i486-linux -> i486-suse-linux
* Wed Mar 27 2002 ihno@suse.de
- removed directories /media/floppy and /media/cdrom
  for s390 and s390x
- removed links /floppy and /cdrom to these directories
  for s390 and s390x
* Wed Mar 13 2002 kukuk@suse.de
- Add more /var/adm subdirectories
* Sat Mar  9 2002 kukuk@suse.de
- Add /etc/httpd and /etc/httpd/modules (needed by more packages
  than only apache).
* Sat Mar  9 2002 kukuk@suse.de
- Add /usr/share/sgml and /usr/share/sgml/docbook
* Fri Mar  8 2002 kukuk@suse.de
- Add /usr/share/sounds and /usr/share/icons
* Fri Mar  8 2002 kukuk@suse.de
- Add /usr/lib/pkgconfig to filelist
* Mon Feb 25 2002 schwab@suse.de
- Don't add lib64 on ia64.
* Wed Feb 20 2002 froh@suse.de
- added {,/usr,/usr/local,/usr/X11R6}/lib64 for s390x, ia64 and sparc64
* Sun Feb 17 2002 kukuk@suse.de
- Add /usr/local/httpd hierachy
* Thu Feb 14 2002 draht@suse.de
- added dir /tmp/.ICE-unix root.root 1777 (#13261)
* Fri Jan 18 2002 ro@suse.de
- added /var/spool/clientmqueue as home for mail user
* Wed Jan 16 2002 ro@suse.de
- moved /usr/cyrus to /usr/lib/cyrus
* Thu Jan 10 2002 ro@suse.de
- removed /etc/rc.config.d
- removed /usr/games/{bin,lib} (#7788)
* Fri Jan  4 2002 olh@suse.de
- remove /macboot and /macos
* Wed Dec 12 2001 ro@suse.de
- added /etc/sysconfig
* Wed Dec 12 2001 ro@suse.de
- added /etc/logrotate.d
* Fri Nov 30 2001 kukuk@suse.de
- remove compat cdrom and floppy link (will be created by YaST2)
- remove /usr/etc and /usr/man (obsolete)
- remove /usr/spool (obsolete)
* Thu Nov 22 2001 ro@suse.de
- removed openwin dirs and fsuite dirs
* Wed Oct 17 2001 ro@suse.de
- removed Provides for package name
* Sat Sep 22 2001 kukuk@suse.de
- Add /var/adm/SuSEconfig to file list
* Fri Sep  7 2001 ro@suse.de
- added homedir for db4web user
* Mon Aug 20 2001 ro@suse.de
- added /etc/profile.d and /etc/permissions.d to dirlist
- removed homedirs for dropped users: lnx, yard, ixess, virtuoso,
    nps, skyrix, dbmaker, fixadm, fib, fixlohn, codadmin
* Thu Jul 12 2001 ro@suse.de
- move skyrix home to /opt/skyrix
* Wed Jul 11 2001 ro@suse.de
- removed informix home dir (#9136)
* Wed May  2 2001 kukuk@suse.de
- Use _target_cpu, not RPM_ARCH
* Mon Apr 30 2001 ro@suse.de
- added sapdb home /var/opt/sapdb
* Wed Apr 25 2001 ro@suse.de
- moved /cdrom and /floppy to /media and added links
* Tue Apr  3 2001 kukuk@suse.de
- Remove i486-linux-libc6 -> not used
    i486-linux-libc5 -> is in shlibs5
    i486-linuxaout -> not used any longer
    i486-sysv -> is in ibcs2
* Fri Mar 16 2001 kukuk@suse.de
- remove rwho spool directory, it is in the rwho package
* Thu Jan 18 2001 ro@suse.de
- deleted db2 home dirs (/usr/lib/db2 and below)
* Wed Jan 10 2001 ro@suse.de
- added /tmp/.X11-unix mode 1777
* Mon Jan  8 2001 ro@suse.de
- added perforce home-dir
* Wed Dec 20 2000 bk@suse.de
- make /var/run constistent with perms change in /etc/permissions:
  root.root 755, fix for bug #3857
* Tue Dec 19 2000 ro@suse.de
- added new dirs from aaa_base
* Mon Dec 18 2000 ro@suse.de
- changed mysql to /var/lib/mysql
* Thu Dec 14 2000 ro@suse.de
- added usr/local/etc
* Wed Dec 13 2000 kukuk@suse.de
- Fix etc/rc.d link [Bug 4627]
* Mon Dec 11 2000 ro@suse.de
- added susehelp dirs
* Wed Dec  6 2000 bk@suse.de
- Add /usr/share/misc (used by util-linux, file, more and ncurses)
* Wed Nov 29 2000 kukuk@suse.de
- Add /var/lib/pam_devperm
* Mon Nov 27 2000 ro@suse.de
- fixes for /sbin/init.d -> /etc/init.d
* Thu Nov 16 2000 ro@suse.de
- added /etc/init.d
* Fri Nov  3 2000 ro@suse.de
- added pop home dir
* Fri Oct 27 2000 ro@suse.de
- added wnn home dir
* Wed Sep  6 2000 ro@suse.de
- added usr/src/packages
* Wed Aug 23 2000 ro@suse.de
- added home dir for vscan user
* Sat Jul 29 2000 kukuk@suse.de
- change /etc/news to 0750 news.news [Bug #3661]
* Fri Jul 21 2000 kukuk@suse.de
- Follow aaa_base change and rename skyrix32 to skyrix36
* Fri Jul 21 2000 kukuk@suse.de
- Remove user empress home directory [Bug #3464]
* Sat Jul 15 2000 kukuk@suse.de
- Rename /var/catman -> /var/cache/man
* Sun Jun 25 2000 kukuk@suse.de
- Add /usr/src
* Thu Jun 22 2000 kukuk@suse.de
- Remove /usr/info (same reasons as for /usr/doc)
* Tue May 30 2000 kukuk@suse.de
- Add /usr/share/{nls,tmac} for FHS 2.1
* Sat May 27 2000 kukuk@suse.de
- Add group tag
* Wed May 17 2000 kukuk@suse.de
- Make /var/games a directory
* Tue May 16 2000 kukuk@suse.de
- Add /etc/opt and /var/cache (used but no owner)
- Add /usr/share/games, /var/cache/fonts and /var/lib/misc for FHS
- Add Link /var/mail -> /var/spool/mail for FHS 2.1
- Add Link /var/games -> /var/lib/games (FHS)
* Fri May 12 2000 ro@suse.de
- added home dir for zope /var/lib/zope
* Tue May  9 2000 ro@suse.de
- added home dir for codadmin /var/lib/codadmin
* Thu Apr 27 2000 ro@suse.de
- added /var/lib/{games,wwwrun,firewall,nobody}
* Mon Apr 17 2000 ro@suse.de
- added /usr/local/{games,sbin,share,src},/usr/share/doc  (#2748)
- added /var/opt (#2744)
* Mon Apr  3 2000 ro@suse.de
- fixed for other archs
* Thu Mar  2 2000 schwab@suse.de
- Add arch directory for ia64
* Tue Feb 22 2000 ro@suse.de
- added ingres home-directory
* Mon Feb 21 2000 ro@suse.de
- fixed skyrix-home
* Tue Feb 15 2000 ro@suse.de
- rebuilt specfile: don't use a tar but a list of directories to
  generate
* Sun Jan 30 2000 olh@suse.de
- add the directories /macboot /macos
  remove them in %%post on an none PowerMac machine
* Wed Jan 19 2000 ro@suse.de
- added usr/share/{info,man} and usr/share/man/man[1-9n]
- removed usr/i486* on non-x86 and added corresponding dirs
  for alpha,ppc,sparc
- added /etc/uucp
* Mon Dec  6 1999 ro@suse.de
- moved uucp-home to /var/spool/uucp
* Fri Nov 12 1999 bs@suse.de
- fixed ownership of ibmdb2 home directories.
* Mon Nov  1 1999 ro@suse.de
- moved oracle-home to /opt/oracle
* Wed Oct 27 1999 ro@suse.de
- added ~ for dpbox
- removed / from rpm-filelist
* Mon Oct 25 1999 ro@suse.de
- added ~ for mysql
* Tue Sep 21 1999 bs@suse.de
- added ~ for oracle.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 27 1999 ro@suse.de
- added home directories for fixlohn, fixadm and fib
* Thu Jul 29 1999 bs@suse.de
- added home dirs of nps, skyrix and dbmaker
- added the directories /etc/cron.daily /etc/ppp
  /usr/doc/packages/aaa_base /usr/doc/support
* Mon Jul 12 1999 bs@suse.de
- added var/adm/notify/*
* Thu Jul  1 1999 ro@suse.de
- removed /var/texfonts from package (closing bug 20)
* Tue Jun  1 1999 ro@suse.de
- added cyrus home dir
* Fri May 21 1999 ro@suse.de
- added postfix home dir
* Tue Apr 20 1999 ro@suse.de
- set gdm-home /var/lib/gdm to mode 750
* Mon Apr 19 1999 ro@suse.de
- added home dir for gdm user
* Tue Mar 30 1999 bs@suse.de
- set permissions of /floppy and /cdrom back to 755 (000 leads to
  massive problems with nfsd)
* Tue Mar 23 1999 bs@suse.de
- added home dir for fnet user.
* Mon Mar 22 1999 bs@suse.de
- set permissions of /mnt to 755 (a lot of people mount things not on
  but under /mnt - e.g. /mnt/disk1)
* Tue Mar  9 1999 ro@suse.de
- added home directories for ibmdb2 users: db2inst1, db2fenc1 and db2as
* Thu Jan  7 1999 bs@suse.de
- added /etc/news
* Sat Dec 12 1998 bs@suse.de
- added /opt/virtuoso-lite
* Fri Dec 11 1998 bs@suse.de
- set standard mount points (/cdrom, /floppy, /mnt) to 000.
* Sun Dec  6 1998 bs@suse.de
- added directories /usr/i486-*
* Fri Nov 27 1998 bs@suse.de
- added symlink /usr/lib/X11
* Thu Nov 26 1998 bs@suse.de
- added /floppy
* Wed Nov 18 1998 bs@suse.de
- added rc.config.d
* Fri Oct 23 1998 ro@suse.de
- added home directory for the user named
* Thu Aug 13 1998 bs@suse.de
- added home directories for the users news, uucp, amanda, ixware
  and informix.
- added a check, if all home directories do exist.
* Wed May 27 1998 bs@suse.de
- added home /usr/lib/ircd for system user irc.
* Fri Apr 17 1998 bs@suse.de
- added /boot
* Fri Apr  3 1998 bs@suse.de
- fixed ownership od /usr/empress
* Thu Mar 26 1998 bs@suse.de
- added some symlinks to directories (/usr/tmp, /usr/spool, ...)
- added /var/spool/rwho
* Mon Feb  9 1998 bs@suse.de
- deleted /usr/postgres
- added /usr/X11R6/lib/X11/app-defaults
* Fri Nov 28 1997 bs@suse.de
- changed /usr/local/ftp to root.root
* Tue Nov 18 1997 bs@suse.de
- added /var/lock/subsys
* Mon Nov 17 1997 bs@suse.de
- added postgress home dir (/var/lib/pgsql)
* Sun Nov 16 1997 bs@suse.de
- ready for autobuild
